/*

 $Id: timer.h,v 1.4 1999/08/03 12:56:04 pfeiffer Exp $

 KNotes -- Notes for the KDE project

 Copyright (C) Bernd Johannes Wuebben
               wuebben@math.cornell.edu
	       wuebben@kde.org

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

 */

#ifndef __KPOSTIT_TIMER__
#define __KPOSTIT_TIMER__

#include <qapplication.h>

class MyTimer : public QObject{

public:
  MyTimer(){
    startTimer( 1000 );
  }

protected:
  virtual void timerEvent( QTimerEvent * );
  void 	       playSound( QString );

public:
  void start();
  void stop();
};

class SaveTimer : public QObject{

public:
  SaveTimer(){
    startTimer(15*60* 1000 ); // 15 Minutes
  }

protected:
  virtual void timerEvent( QTimerEvent * );

public:
  void start();
  void stop();
};

#endif
